import request from '@/utils/request'

// 查询管理老师信息列表
export function managementTeacherPage (query) {
  return request({
    url: '/info/managementTeacher/page',
    method: 'get',
    params: query
  })
}
// 新增管理老师信息
export function managementTeacherAdd (data) {
  return request({
    url: '/info/managementTeacher/add',
    method: 'post',
    data
  })
}
// 获取管理老师信息详细信息
export function managementTeacherInfo (id) {
  return request({
    url: `/info/managementTeacher/info/${id}`,
    method: 'get',
  })
}
// 修改管理老师信息
export function managementTeacherEdit (data) {
  return request({
    url: `/info/managementTeacher/edit`,
    method: 'post',
    data
  })
}
// 删除管理老师信息
export function managementTeacherDel (ids) {
  return request({
    url: `/info/managementTeacher/del/${ids}`,
    method: 'post',
  })
}
// 启用-禁用 管理老师
export function managementTeacherUpdateStatus (data) {
  return request({
    url: `/info/managementTeacher/update-status`,
    method: 'post',
    data
  })
}